;******************************************************************************
; Projeto - Ring_comm
; Arquivo - Ring_comm.asm
; Desenv. - Eng. Márcio José Soares
; Versão  - 1.0
; Data    - 22/05/2023
;
; Comunicação RS-232 em anel com outros 4 dispositivos
; 
; Extras:
; CI UART 8250 presente na placa para comunicação RS-232
; Controle de LCD 16x2 através da PPI8255
;
; Compilador: pasmo -d -v Ring_comm.asm Ring_comm.bin > Ring_comm.lst
;
; Pinos:
; RS232     DB09
; ------------------
; TX		3
; RX		2
; GND		5
;
; LCD       PPI8255
; ------------------
; EN(6)     PA0
; RS(4)     PB0
; D4(11)    PB4
; D5(12)    PB5
; D6(13)    PB6
; D7(14)    PB7
;
; Chaves    PPI8255
;-------------------
; S1        PC0
; S2        PC1
; S3        PC2
;
;------------------------------------------------------------------------------
;
; Últimas alterações:
;
; em 22/05/2023:
;   - criado esse arquivo/projeto
; 
; em 24/05/2023:
;	- inicio dos testes de envio de caracteres (modo debug para o PC)
;     Testes ok!!!
;
; em 25/05/2023:
;	- teste do uso da int com dados OK
;   - teste do envio de dados para terminais 1, 2 e 3 OK
;   - teste da recepção dos dados vindos dos demais terminais OK
;   - teste da apresentação dos dados no LCD OK
;	- testes para primeira versão ok!!!
;   - divulgando no site e no canal!
;------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
; Incluí constantes e variáveis para uso dos recursos do programa monitor 
; liberados para o usuário - novo a partir de 22/05/2023
;
include "../drZ80_uC.inc"

;-------------------------------------------------------------------------------
; Declara constantes gerais do módulo!
;
CR              equ     0DH             ; ENTER
LF              equ     0AH             ; Line Feed
ACK 			equ		06H				; caracter ACK

;-------------------------------------------------------------------------------
; Protocolo ring by Arne! ;)
;
HEADER			equ		'@'				; header
POSHEADER       equ      0
POSDISPS        equ      1
POSQTBYTES      equ      2
POSDATA         equ      3

ENVIO           equ      6
TEMDADO			equ      7

NRDISP   		equ		 04H			; número do dispositivo na rede

TAMDATA         equ      0EH  			; apenas 14 bytes para dados
TAMBUF          equ      (03H + TAMDATA + 01H)
TAMMSG			equ		 09H			; tamanho da mensagem para outros terminais

;-------------------------------------------------------------------------------
; LCD
;
RS_ON           equ     01H             ; bit de controle RS do LCD
RS_OFF          equ     0FEH            ; bit de controle RS do LCD invertido


;-------------------------------------------------------------------------------
; Declara posição inicial da RAM - inicio do programa do usuário
;
                org     8000H           ; endereço inicial da RAM e programa do usuário
                jr      main            ; desvia para main
                
;-------------------------------------------------------------------------------
; Declara posição para atendimento de ints do usuário!
; Novo! Apenas para a versão drZ80 v2.0 de 22/05/2023
;

				org		8004H			; aqui tratamento da int do teclado - sempre!!!!
                di						; desliga INTs
                jp		trata_int		; desvia para realizar o tratamento


                org		8008H			; aqui tratamento da int NMI para RS232 - sempre!!!!
                di						; desliga INTs
                jp		trata_intNMI	; desvia para realizar o tratamento

;-------------------------------------------------------------------------------
; Declara variáveis
;
myout           db      1               ; var de saida para dados
mydata          db      1               ; var para colocar dados no LCD
myaux3          db      1
myflags         db      1				; flags para receção do protoloco
counter         db      1               ; contador para dados recebidos
nrdisps         db      1               ; nr dos dispositivos
qtbytes         db      1               ; quantidade de bytes a receber
countmsg		db		1				; contador de mensagens

buffer          ds      TAMBUF			; define o buffer na RAM

;-------------------------------------------------------------------------------
; Subrotina principal
;
main:           call    t_500ms         ;aguarda

				ld      a,00H			; prepara para iniciar vars
				
				ld      hl,myflags      
				ld      (hl),a
				
				ld      hl,counter
				ld      (hl),a
				
				ld 		hl,countmsg
				ld    	(hl),a
				
				call	wrzerodisp		; apaga displays
				
				call    initLCD         ; configura LCD
                call    clearLCD		; limpa LCD
                call    snd2SPC			; envia 2 chars dummies
                
                call    clearLCD		; limpa novamente
                ld      hl,msgLCD		; ponteiro para mensagem
                call    sendmsg         ; envia mensagem para LCD    
                
                ld		b,6				; carrega para aguardar
main_00:        call    t_500ms         ; aguarda
                djnz	main_00			; faz 6 vezes = 500ms x 6 = 3000ms
                
                call    clearLCD		; limpa novamente
                ld      hl,msgRing		; novo ponteiro
                call    sendmsg         ; envia mensagem para LCD   
                
                call    t_100ms         ; aguarda
	
                im		1				; ints em modo 1
                ei						; habilita ocorrência de INTs - apenas NMI

main_LC:		ld		hl,myflags		; pega end da var
				ld 		a,(hl)
				bit		TEMDADO,a		; testa, se setado desvia
				call    nz,trataBuf		; desvia se tiver um buffer a tratar
								
getkeys:	    call	rdC8255			; lê port C do 8255
				ld      hl,mydataPC		; pega end da var
				ld      a,(hl) 			; coloca o conteúdo em a
				and     0FH				; só interessam bits 0, 1, 2 e 3
				ld		c,a             ; salva como tecla anterior
				
				ld 		b,01H			; nr do terminal que vai receber
				cp      0EH				; primeira tecla pressionada
				jr      z,sndterm		; envia mensagem para terminal 1
				
				ld 		b,02H			;
				cp      0DH				; segunda tecla pressionada
				jr      z,sndterm       ; envia mensagem para terminal 2
				
				ld 		b,03H			;
				cp      0BH   			; terceira tecla pressionada
				jr      z,sndterm       ; envia mensagem para terminal 3
				jr		main_END		; desvia para fim
				
sndterm:		call	rdC8255			; verifica se soltou a tecla
				ld      hl,mydataPC     ; pega end da var
				ld      a,(hl)			; novamente em a
				and     0FH				; só interessam bits 0, 1, 2 e 3
				cp      c               ; compara com c
				jr      nz,sndtermC		; se soltou, continua
				call	t_50ms			; bounce para teclas
				jr      sndterm         ; senão, trava até soltar!
				
sndtermC:		ld 		a,b				; pega nr do terminal a enviar
				call	wrAdisp5_6		; escre A nos displays 5 e 6
				
				ld 		hl,myflags		; pega end da var 
				bit     POSHEADER,(hl)	; esta recebendo?!
				jr      nz,main_END		; desvia, não pode enviar!
				
				set     ENVIO,(hl)		; avisa que vai iniciar um envio
					
				ld      hl,nrdisps		; pega end da var
				ld      a,NRDISP		; terminal que envia no MSB
				rla						; gira a esquerda 4x
				rla 
				rla 
				rla 
				or      b				; terminal de destino no LSB
				ld      (hl),a          ; resultado do OR em a, carrega na var
				
				call    ldmsgTerm		; carrega msg a enviar no buffer
				
				ld		hl,buffer		; ponteiro para buffer em HL
				call	wrmonRS232		; envia a mensagem!!!
				
				ld 		hl,myflags      ; carrega end da var
				res     ENVIO,(hl) 		; reseta flag! libera receber
				
main_END:		call    t_50ms			; temporiza - bounce para teclas
				jp 		main_LC			; trava aqui
				
                halt                    ; se passar ... system halt!
         
;-------------------------------------------------------------------------------
; Subrotina para tratamento da NMI ligada ao 8250
; inicio da subrotina dentro do programa monitor!!!
; aqui apenas tratamento e fechamento da int - retorno!
;
trata_int:		ld		hl,mytec			; pega var onde estara o valo da tecla
				ld      a,(hl)				; coloca em A
				
endint:         exx                         ; restaura registradores
                ex      af,af'              ;
                
                ei                          ; habilita novamente a int
                reti                        ; retorna da int
                
;-------------------------------------------------------------------------------
; Subrotina para tratamento da NMI ligada ao 8250
; inicio da subrotina dentro do programa monitor!!!
; aqui apenas tratamento e fechamento da int - retorno!
;
trata_intNMI:	ld      bc,mydataRX		; pega end da var
				ld      a,(bc)			; pega o conteúdo
				ld      d,a             ; salva em d

				ld 		hl,myflags		; pega variável com posição do protocolo
				
				bit 	ENVIO,(hl)		; testa se está enviando
				jr      nz,trata_NMIEND	; se sim, desvia! não pode receber
				
				bit     POSHEADER,(hl)	; testa para saber se já recebeu header
				jr      z,tstHeader		; se zero, pode ser header
				
				bit     POSDISPS,(hl)	; se não é header, pode ser nr dos dispositivos
				jr      z,recDisps      ; recebe
				
				bit     POSQTBYTES,(hl) ; se não é nr dos dispositivos, é quantidade
				jr      z,recQuant      ; testa
			
				jr      recData			; desvia para receber dados
				
tstHeader:		cp      HEADER          ; compara com HEADER
				jr      nz,trata_NMIEND	; não é header, desvia para o fim - ignora

ehHeader:		set     POSHEADER,(hl)	; set flag avisando que recebeu flag
				jr      saveData        ; desvia para salvar
				
recDisps:		set 	POSDISPS,(hl)	; seta avisando que recebeu
				ld      hl,nrdisps
				ld      (hl),a          ; salva
				jr      saveData        ; apenas salva

recQuant:		set     POSQTBYTES,(hl) ; seta avisando que recebeu
				ld      hl,qtbytes      ; pega end da var
				ld      (hl),a          ; guarda
				jr      saveData        ; desvia para salvar no buffer
				
recData:		set     POSDATA,(hl)    ; seta avisando que recebeu
								
saveData:		ld      hl,counter      ; pega end da var
				ld      a,(hl)          ; pega o conteúdo
				ld      c,a             ; guarda em c
				ld      b,00H			; em b 0
				ld      hl,buffer       ; pega endereço do buffer
				add     hl,bc           ; soma para posicionar
				ld      (hl),d          ; guarda o dado recebido no buffer
				
				ld      hl,counter      ; pega end da var
				inc     (hl)			; incrementa hl
				ld      a,(hl)			; carrega em A
				
				ld      hl,qtbytes    	; pega a quantidade de bytes a receber
				ld      b,(hl)          ; em b conteúdo
				
				sub		b               ; counter - qt bytes a receber
				cp 		03H				; se valor = 03H, tudo recebido!
				jr      nz,trata_NMIEND ; se diferente desvia para continuar
				
				ld      hl,counter      ; pega end da var
				ld      a,(hl)          ; pega o conteúdo
				ld      c,a             ; guarda em c
				ld      b,00H			; em b 0
				ld      hl,buffer       ; pega endereço do buffer
				add     hl,bc           ; soma para posicionar
				ld      a,00H			; insere zero para
				ld      (hl),a          ; fechar o buffer
				
				ld      hl,myflags		; end da var
				set     TEMDADO,(hl)    ; avisa que tem dado para tratar
				
trata_NMIEND:   exx						; restaura regs salvos pelo
				ex 		af,af'			; monitor na entrada da int
				
				ei						; habilita novamente as ints
				retn      				; retorna da nmi
			
;-------------------------------------------------------------------------------
; subrotina para tratar dado recebido e enviar para LCD
;			
trataBuf:		ld   	hl,nrdisps 		; pega end da var 
				ld      a,(hl)          ; em a o conteúdo da var
				
				and     0x0F            ; limpa MSB
				cp      NRDISP 			; testa para ver se envio é para este dispositivo
				jr      nz,sendNext     ; se não é para este dispositivo, envia buffer!
				
				ld      hl,qtbytes      ;
				ld      a,(hl)
				cp      01H             ; se tem apenas 1 char no buffer
				jr      z,trataBFEND    ; pode ou não ser getACK, então finaliza
				
				ld 		hl,countmsg		; incrementa contador de mensagens
				inc     (hl)
				
writeNRdisp:	ld      hl,mydata		; pega end da var
				ld      a,80H           ; endereço para linha 1 do LCD
				add     a,02H           ; coluna 2
				ld      (hl),a          ; carrega valor
				call	scomLCD 		; envia comando
				
				ld      hl,nrdisps      ; pega var nr dos dispositivos
				ld      a,(hl)			; conteúdo
				and     0F0H            ; limpa LSB
				rra 					; coloca MSB no LSB
				rra
				rra
				rra
				
				call	sendHexLCD		; escreve no LCD
				
				
writeQtbytes:	ld      hl,mydata		; pega end da var
				ld      a,80H           ; endereço para linha 1 do LCD
				add     a,07H           ; coluna 7
				ld      (hl),a          ; carrega valor
				call	scomLCD 		; envia comando
				
				ld      hl,qtbytes      ; pega var nr dos dispositivos
				ld      a,(hl)			; conteúdo
				and     0FH             ; limpa MSB
							
				call	sendHexLCD		; escreve no LCD
				
writeNrMsg:		ld      hl,mydata		; pega end da var
				ld      a,80H           ; endereço para linha 1 do LCD
				add     a,0CH           ; coluna 12
				ld      (hl),a          ; carrega valor
				call	scomLCD 		; envia comando
				
				ld		hl,countmsg    	; pega end da var
				ld      a,(hl)          ; em A o conteúdo
				
				call	sendHexLCD		; escreve no LCD

writeDataBuf:	ld      hl,mydata		; pega end da var
				ld      a,0C0H          ; endereço para linha 2 do LCD
				add     a,02H           ; coluna 2
				ld      (hl),a          ; carrega valor
				call	scomLCD 		; envia comando
				
				ld		b,0EH           ; carrega b com 14
cleanLin2LCD:	ld      a,' '			; espaço
				ld      hl,mydata       ; carrega na var
				ld      (hl),a          ; carrega na var
				call	schLCD 			; envia comando
				djnz 	cleanLin2LCD    ; envia chars
				
				ld      hl,mydata		; reposiciona
				ld      a,0C0H          ; endereço para linha 2 do LCD
				add     a,02H           ; coluna 2
				ld      (hl),a          ; carrega valor
				call	scomLCD 		; envia comando
				
				ld      hl,buffer       ; pega end do buffer
                ld      b,00H           ; em b zero
                ld      c,POSDATA       ; em c a posição do dado
				add     hl,bc           ; soma
				call	sendmsg			; envia mensagem para display
				jr      trataBFEND      ; desvia para fim
								
sendNext:		ld 		hl,buffer       ; pega end da var
				call	wrmonRS232		; envia usando função do programa monitor
				
trataBFEND:		ld 		a,00H			; zera para novo contato
				ld      hl,myflags
				ld      (hl),a 			; flags zerados
				
				ld      hl,qtbytes		; 
				ld      (hl),a			; quantidade de bytes zerados
				
				ld      hl,nrdisps
				ld 		(hl),a			; nr do dispositivo zerado
				
				ld 		hl,counter		; contador zerado
				ld      (hl),a
				
				ret						; retorna
		
;-------------------------------------------------------------------------------
; Subrotina para csrregar o buffer com a msg a ser enviada via porta RS232
; 
ldmsgTerm:		ld 		hl,buffer		; pega end do início do buffer
				ld 		a,HEADER
				ld      (hl),a			; carrega buffer com HEADER
				inc     hl				; incrementa ponteiro
				
				ld      bc,nrdisps		; pega nr dos dispositivos
				ld      a,(bc)          ; carrega A com conteúdo da var 

				;--------------------------------------------------------------
				; modo debug
				;
				;call	bin2hex			; converte binario para HEX ASCII
				;ld      (hl),d
				;inc     hl
				;ld      (hl),e
				;inc     hl
				
				;ld      a,TAMMSG
				;call	bin2hex
				;ld      (hl),d
				;inc     hl
				;ld      (hl),e
				;inc     hl
                ;--------------------------------------------------------------
                
                ;--------------------------------------------------------------
                ; modo real
				ld      (hl),a          ; carrega buffer com nr dos terminais
				inc		hl				; incrementa ponteiro
				ld      a,TAMMSG		; insere tamanho da mensagem
				ld      (hl),a 			; carrega buffer com tamanho da MSG
				inc     hl              ; incrementa ponteiro
                ;--------------------------------------------------------------
                
				ld      bc,msg2Terms	; pega end da mensagem
ldmsgTermC:		ld      a,(bc)			; pega conteúdo
				cp      0FFH			; compara com final FF 
				ret     z               ; retorna se chegou ao fim
				
				ld		(hl),a 			; carrega buffer com mensagem
				inc     hl              ; incrementa ponteiro do buffer
				inc     bc              ; incrementa ponteiro da mensagem

				jr      ldmsgTermC		; faz até chegar ao fim!
				
;-------------------------------------------------------------------------------
; subrotina para escrever um caracter em HEXA no LCD
; char em A
;
sendHexLCD:		call    bin2hex         ; converte para HEXA ASCII
				push	de				; salva reg
				ld      a,d             ; pega o MSB 
				ld      hl,mydata       ; pega end da var de transferência
				ld      (hl),a
				call    schLCD          ; envia para o LCD
				
				pop 	de				; restaura
				ld      a,e             ; pega o LSB
				ld      hl,mydata       ; pega end da var de transferência
				ld      (hl),a
				call    schLCD          ; envia para o LCD

				ret
				
;-------------------------------------------------------------------------------
; subrotina para enviar msg para a LCD
; ponteiro da mensagem em HL
;
sendmsg:        ld      a,(hl)          ;pega conteudo
                ld      b,a             ;salva em b
                cp      00H             ;compara com final
                ret     z               ;retorna se chegou ao fim
                
                cp      LF              ;compara com LF
                jp      nz,sndcont      ;se nao, continua
                call    lin2LCD         ;muda para linha 2 do LCD
                inc     hl
                jr      sndcontLF       ;pula para não enviar o LF
                
sndcont:        ld      de,mydata       ;pega end da var de envio
                ld      a,b             ;restaura a com b
                ld      (de),a          ;coloca conteúdo da mensagem em a
                inc     hl              ;incrementa a posição de hl
                
                call    schLCD          ;envia char para LCD
sndcontLF:      call    t_50ms          ;aguarda
                
fsndstrlc:      jr      sendmsg        ;continua ate o fim

;-------------------------------------------------------------------------------
; Subrotina para mudar para linha 2 do LCD
;
lin2LCD:        push    hl

                ld      hl,mydata       ;coloca na var o char a ser escrito
                ld      a,0C0H          ;apaga LCD e coloca na coluna 1
                ld      (hl),a
                call    scomLCD         ;muda de linha no LCD
                
                pop     hl
                
                ret

;-------------------------------------------------------------------------------
; Subrotina para apagar o LCD
;
clearLCD:       ld      hl,mydata       ;coloca na var o char a ser escrito
                ld      a,01H           ;apaga LCD e coloca na coluna 1
                ld      (hl),a
                call    scomLCD         ;muda de linha no LCD

                ret
                
;-------------------------------------------------------------------------------
; Envia dois caracteres dummies antes de enviar uma string
;
snd2SPC:        ld      hl,mydata
                ld      a,' '
                ld      (hl),a
                call    schLCD
                call    t_50ms
                
                ld      hl,mydata
                ld      a,' '
                ld      (hl),a
                call    schLCD
                call    t_50ms

                ret

;-------------------------------------------------------------------------------
; Envia um char para o LCD - usa modo 4 bits
;
schLCD:         push    hl
                push    bc

                ld      hl,mydata       ;pega endereco da var
                ld      a,(hl)          ;pega o conteudo
                and     0F0H            ;limpa a parte menos significativa
                or      RS_ON           ;liga o pino de RS

                call    wrB8255A        ;envia A para portB
                call    EN_on           ;liga o pino EN - pulsa EN
                call    t_50us          ;aguarda
                call    EN_off          ;desliga o pino EN

                ld      hl,mydata       ;volta a pegar o end da var
                ld      a,(hl)          ;pega o conteudo
                sla     a               ;posiciona o LSB no MSB
                sla     a
                sla     a
                sla     a
                and     0F0H            ;limpa o LSB
                or      RS_ON           ;liga o RS

                call    wrB8255A        ;envia A para portB
                call    EN_on           ;liga o pino EN - pulsa EN
                call    t_50us          ;aguarda
                call    EN_off          ;desliga o pino EN

                pop     bc
                pop     hl
                
                ret

;-------------------------------------------------------------------------------
; Envia um comando para o LCD - usa modo 4 bits de dados
;
scomLCD:        ld      hl,mydata       ;pega endereco da var
                ld      a,(hl)          ;pega o conteudo
                and     0F0H            ;limpa a parte menos significativa
                and     RS_OFF          ;desliga o pino de RS

                call    wrB8255A        ;envia A para portB
                
                call    EN_on           ;liga o pino EN - pulsa EN
                call    t_50us          ;aguarda
                call    EN_off          ;desliga o pino EN

                ld      hl,mydata       ;volta a pegar o end da var
                ld      a,(hl)          ;pega o conteudo
                sla     a               ;posiciona o LSB no MSB
                sla     a
                sla     a
                sla     a
                and     0F0H            ;limpa o LSB
                and     RS_OFF          ;desliga o RS

                call    wrB8255A        ;envia A para portB
                call    EN_on           ;liga o pino EN - pulsa EN
                call    t_50us          ;aguarda
                call    EN_off          ;desliga o EN de strobe

                ret

;-------------------------------------------------------------------------------
; Subrotina para configurar/iniciar o LCD  - RS=0 e WR=0
; Le bytes em _initlcd e envia via porta paralela
; Configuracao adotada: modo 4 bits de dados, 2 linhas, caracter 5x7, cursor piscando
;
initLCD:        ld      a,00H           ;sao 5 bytes a enviar, comecando por zero
                ld      hl,myaux3       ;carrega endereco
                ld      (hl),a          ;guarda

initLCDloop:    ld      de,myaux3       ;pega o endereco da var
                ld      b,00H           ;zera a var
                ld      a,(de)          ;pega o conteudo de myaux3
                ld      c,a             ;carrega em c

                ld      hl,_inilcd      ;carrega endereco da var de configuracao
                add     hl,bc           ;posiciona o ponteiro
                ld      a,(hl)          ;pega primeiro byte
                ld      hl,mydata       ;pega endereco da var
                ld      (hl),a          ;coloca valor na var

                call    scomLCD         ;envia o comando para o LCD

                ld      hl,myaux3       ;carrega endereco
                ld      a,(hl)          ;pega conteudo
                inc     a               ;decrementa a
                ld      (hl),a          ;guarda conteudo
                cp      05H             ;compara com final - sao 7 comandos agora
                jp      nz,initLCDloop  ;se nao eh ainda o valor

                ret                     ;detectado fim, retorna!
                
;-------------------------------------------------------------------------------
; Subrotina strobe_on - liga pino de strobe
;
EN_on:          ld      hl,myEN         ;carrega end da var
                ld      a,01H           ;carrega valor ON
                jr      myEN            ;desvia

;-------------------------------------------------------------------------------
; Subrotina strobe_off - desliga pino de strobe
;
EN_off:         ld      hl,myEN         ;carrega end da var
                ld      a,00H           ;carrega valor OFF

;-------------------------------------------------------------------------------
; Subrotina mystrobe - liga/desliga pino de strobe
;
myEN:           call    wrA8255A        ;envia dado para portA
                ret                     ;retorna
              
;-------------------------------------------------------------------------------
; Subrotina converter um byte em formato hexadecimal ASCII
;
; Entradas: em A valor do dado a ser convertido!
; Saídas  : em D byte com ASCII high, em E byte com ASCII Low
;
bin2hex:        push	hl
				push    bc
                push    af

                and     0F0H            ; separa apenas mais significativo
                rra                     ; gira para colocar MSB no LSB
                rra                     ; sao 4 bits
                rra
                rra
                and     0FH             ; limpa o MSB
                ld      c,a
                ld      b,00H
                ld      hl,_BCD         ; pega endereco do BDC
                add     hl,bc           ; soma o ponteiro
                ld      a,(hl)
                ld      d,a             ; guarda MSB em D

                pop     af              ; restaura

                and     0FH             ; separa apenas menos significativo
                ld      c,a
                ld      b,00H
                ld      hl,_BCD         ; pega endereco do BDC
                add     hl,bc           ; soma o ponteiro
                ld      a,(hl)
                ld      e,a             ; guarda LSB em e

                pop     bc
                pop 	hl
                ret                     ;retorna
                
;-------------------------------------------------------------------------------
; Dados para LCD - inicializacao
; comandos para inicializar o LCD - modo 4 bits
_inilcd:        db       02H, 28H, 06H, 0FH, 01H       

;-------------------------------------------------------------------------------
; Mensagem para LCD_drZ80
;
msgDummie:      db      '  ',00H

msgLCD:         db      '   BEM-VINDO AO ',LF
                db      '   LAB do Arne  ',00H
                
msgRing:		db		' T>   Q>   C>   ',LF
				db      '->              ',00H

;--------------------------------------------------------------------------------
; modo debug
;msg2Terms:		db		'PLACA Z80',CR,LF,00H,0FFH

;--------------------------------------------------------------------------------
; modo real
msg2Terms:		db		'PLACA Z80',00H,0FFH

_BCD:           db  30H, 31H, 32H, 33H, 34H, 35H, 36H, 37H
                db  38H, 39H, 41H, 42H, 43H, 44H, 45H, 46H,00H 
                
				end
